.. Stamp Processing documentation master file, created by
   sphinx-quickstart on Wed Sep 15 12:23:19 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Stamp Processing's documentation!
===============================================

.. toctree::

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`